==> qtjambi-qt3dcore-debuginfo-macos-5.15.17.jar: sources/QtJambi3DCore/QPropertyUpdatedChange_shell.cpp <==
#include "QPropertyUpdatedChange_shell.h"
#include <QtJambi/Cast>

void deleter_Qt3DCore_QPropertyUpdatedChange(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DCore::QPropertyUpdatedChange")
    Qt3DCore::QPropertyUpdatedChange *_ptr = reinterpret_cast<Qt3DCore::QPropertyUpdatedChange *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QPropertyUpdatedChange_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QPropertyUpdatedChange_shell) ); }

jmethodID QPropertyUpdatedChange_shell::__shell_javaMethod(int pos) const { return QPropertyUpdatedChange_shell::__shell()->javaMethod(typeid(Qt3DCore::QPropertyUpdatedChange), pos); }

// emitting (writeShellConstructor)
QPropertyUpdatedChange_shell::QPropertyUpdatedChange_shell(Qt3DCore::QNodeId subjectId0)
    : Qt3DCore::QPropertyUpdatedChange(subjectId0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DCore::QPropertyUpdatedChange::QPropertyUpdatedChange_shell(Qt3DCore::QNodeId subjectId0)", QPropertyUpdatedChange_shell::__shell())
    QPropertyUpdatedChange_shell::__shell()->constructed(typeid(Qt3DCore::QPropertyUpdatedChange));
}

// emitting (writeShellDestructor)
QPropertyUpdatedChange_shell::~QPropertyUpdatedChange_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("Qt3DCore::QPropertyUpdatedChange::~Qt3DCore::QPropertyUpdatedChange()", QPropertyUpdatedChange_shell::__shell())
    QPropertyUpdatedChange_shell::__shell()->destructed(typeid(Qt3DCore::QPropertyUpdatedChange));
}

void QPropertyUpdatedChange_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QPropertyUpdatedChange_shell*>(ptr)->QPropertyUpdatedChange_shell::__shell()->tryDeleteShell(typeid(Qt3DCore::QPropertyUpdatedChange));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QPropertyUpdatedChange(Qt3DCore::QNodeId)
void __qt_construct_Qt3DCore_QPropertyUpdatedChange_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPropertyUpdatedChange(Qt3DCore::QNodeId)")
    jobject subjectId0 = __java_arguments[0].l;
    Qt3DCore::QNodeId __qt_subjectId0 = qtjambi_cast<Qt3DCore::QNodeId >(__jni_env, subjectId0);
    Qt3DCore::QPropertyUpdatedChange *__qt_this = new(__qtjambi_ptr) QPropertyUpdatedChange_shell(__qt_subjectId0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QPropertyUpdatedChange_shell
void __qt_destruct_Qt3DCore_QPropertyUpdatedChange(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DCore::QPropertyUpdatedChange")
    reinterpret_cast<QPropertyUpdatedChange_shell*>(ptr)->~QPropertyUpdatedChange_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DCore::QPropertyUpdatedChange::QPropertyUpdatedChange(Qt3DCore::QNodeId)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QPropertyUpdatedChange_initialize_1native__Lio_qt_qt3d_core_QPropertyUpdatedChange_2Lio_qt_qt3d_core_QNodeId_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject subjectId0)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QPropertyUpdatedChange::QPropertyUpdatedChange(Qt3DCore::QNodeId)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = subjectId0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QPropertyUpdatedChange_0, sizeof(QPropertyUpdatedChange_shell), typeid(Qt3DCore::QPropertyUpdatedChange), true, &deleter_Qt3DCore_QPropertyUpdatedChange, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// Qt3DCore::QPropertyUpdatedChange::setValue(QVariant)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QPropertyUpdatedChange_setValue_1native_1cref_1QVariant__JLjava_lang_Object_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject value0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        Qt3DCore::QPropertyUpdatedChange *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QPropertyUpdatedChange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QPropertyUpdatedChange::setValue(QVariant)", __qt_this)
        QVariant  __qt_value0 = qtjambi_cast<QVariant >(__jni_env, value0);
        __qt_this->setValue(__qt_value0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// Qt3DCore::QPropertyUpdatedChange::value()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QPropertyUpdatedChange_value_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QPropertyUpdatedChange *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QPropertyUpdatedChange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QPropertyUpdatedChange::value()const", __qt_this)
        QVariant __qt_return_value = __qt_this->value();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DCore_QPropertyUpdatedChange(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<Qt3DCore::QPropertyUpdatedChange>("Qt3DCore::QPropertyUpdatedChange", "io/qt/qt3d/core/QPropertyUpdatedChange");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DCore_QPropertyUpdatedChange, {
        ConstructorInfo(&__qt_construct_Qt3DCore_QPropertyUpdatedChange_0, "Lio/qt/qt3d/core/QNodeId;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DCore_QPropertyUpdatedChange);
    registerSizeOfShell(typeId, sizeof(QPropertyUpdatedChange_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<Qt3DCore::QStaticPropertyUpdatedChangeBase, Qt3DCore::QPropertyUpdatedChange>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qt3dcore-debuginfo-macos-5.15.20.jar: sources/QtJambi3DCore/QPropertyUpdatedChange_shell.cpp <==
#include "QPropertyUpdatedChange_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_Qt3DCore_QPropertyUpdatedChange(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DCore::QPropertyUpdatedChange")
    Qt3DCore::QPropertyUpdatedChange *_ptr = reinterpret_cast<Qt3DCore::QPropertyUpdatedChange *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QPropertyUpdatedChange_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QPropertyUpdatedChange_shell) ); }

jmethodID QPropertyUpdatedChange_shell::__shell_javaMethod(int pos) const { return QPropertyUpdatedChange_shell::__shell()->javaMethod(typeid(Qt3DCore::QPropertyUpdatedChange), pos); }

// emitting (writeShellConstructor)
QPropertyUpdatedChange_shell::QPropertyUpdatedChange_shell(Qt3DCore::QNodeId subjectId0)
    : Qt3DCore::QPropertyUpdatedChange(subjectId0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DCore::QPropertyUpdatedChange::QPropertyUpdatedChange_shell(Qt3DCore::QNodeId subjectId0)", QPropertyUpdatedChange_shell::__shell())
    QPropertyUpdatedChange_shell::__shell()->constructed(typeid(Qt3DCore::QPropertyUpdatedChange));
}

// emitting (writeShellDestructor)
QPropertyUpdatedChange_shell::~QPropertyUpdatedChange_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("Qt3DCore::QPropertyUpdatedChange::~Qt3DCore::QPropertyUpdatedChange()", QPropertyUpdatedChange_shell::__shell())
    QPropertyUpdatedChange_shell::__shell()->destructed(typeid(Qt3DCore::QPropertyUpdatedChange));
}

void QPropertyUpdatedChange_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QPropertyUpdatedChange_shell*>(ptr)->QPropertyUpdatedChange_shell::__shell()->tryDeleteShell(typeid(Qt3DCore::QPropertyUpdatedChange));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QPropertyUpdatedChange(Qt3DCore::QNodeId)
void __qt_construct_Qt3DCore_QPropertyUpdatedChange_Qt3DCore_QNodeId(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPropertyUpdatedChange(Qt3DCore::QNodeId)")
    jobject subjectId0 = __java_arguments[0].l;
    Qt3DCore::QNodeId __qt_subjectId0 = qtjambi_cast<Qt3DCore::QNodeId >(__jni_env, subjectId0);
    Qt3DCore::QPropertyUpdatedChange *__qt_this = new(__qtjambi_ptr) QPropertyUpdatedChange_shell(__qt_subjectId0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// Qt3DCore::QPropertyUpdatedChange::QPropertyUpdatedChange(Qt3DCore::QNodeId)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QPropertyUpdatedChange_initialize_1native__Lio_qt_qt3d_core_QPropertyUpdatedChange_2Lio_qt_qt3d_core_QNodeId_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject subjectId0)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QPropertyUpdatedChange::QPropertyUpdatedChange(Qt3DCore::QNodeId)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = subjectId0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QPropertyUpdatedChange_Qt3DCore_QNodeId, sizeof(QPropertyUpdatedChange_shell), typeid(Qt3DCore::QPropertyUpdatedChange), true, &deleter_Qt3DCore_QPropertyUpdatedChange, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QPropertyUpdatedChange_shell
void __qt_destruct_Qt3DCore_QPropertyUpdatedChange(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DCore::QPropertyUpdatedChange")
    reinterpret_cast<QPropertyUpdatedChange_shell*>(ptr)->~QPropertyUpdatedChange_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DCore::QPropertyUpdatedChange::setValue(QVariant)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QPropertyUpdatedChange_setValue_1native_1cref_1QVariant__JLjava_lang_Object_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject value0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        Qt3DCore::QPropertyUpdatedChange *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QPropertyUpdatedChange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QPropertyUpdatedChange::setValue(QVariant)", __qt_this)
        QVariant  __qt_value0 = qtjambi_cast<QVariant >(__jni_env, value0);
        __qt_this->setValue(__qt_value0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// Qt3DCore::QPropertyUpdatedChange::value()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QPropertyUpdatedChange_value_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QPropertyUpdatedChange *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QPropertyUpdatedChange>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QPropertyUpdatedChange::value()const", __qt_this)
        QVariant __qt_return_value = __qt_this->value();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DCore_QPropertyUpdatedChange(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<Qt3DCore::QPropertyUpdatedChange>("Qt3DCore::QPropertyUpdatedChange", "io/qt/qt3d/core/QPropertyUpdatedChange");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DCore_QPropertyUpdatedChange, {
        ConstructorInfo(&__qt_construct_Qt3DCore_QPropertyUpdatedChange_Qt3DCore_QNodeId, "Lio/qt/qt3d/core/QNodeId;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DCore_QPropertyUpdatedChange);
    registerSizeOfShell(typeId, sizeof(QPropertyUpdatedChange_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<Qt3DCore::QStaticPropertyUpdatedChangeBase, Qt3DCore::QPropertyUpdatedChange>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
